<?php
/**
 * White-xmas Theme Customizer
 *
 * @package white-xmas
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function whitexmas_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
}
add_action( 'customize_register', 'whitexmas_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function whitexmas_customize_preview_js() {
	wp_enqueue_script( 'whitexmas_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'whitexmas_customize_preview_js' );

function whitexmas_customizer( $wp_customize ) {
	/* Breadcrumbs */
	$wp_customize->add_section('whitexmas_breadcrumbs',      array(
		'title' => __( 'Breadcrumbs', 'white-xmas' ),
		'priority' => 220,
		)
	);

	$wp_customize->add_setting( 'whitexmas_hide_breadcrumbs',		array(
		'sanitize_callback' => 'whitexmas_sanitize_checkbox',
		)
	);
	$wp_customize->add_control('whitexmas_hide_breadcrumbs',		array(
		'type' => 'checkbox',
		'label' => __( 'Check this box to hide the breadcrumb navigation.', 'white-xmas' ),
		'section' => 'whitexmas_breadcrumbs',
		)
	);

	/* Deer */
	$wp_customize->add_setting( 'whitexmas_hide_deer',		array(
		'sanitize_callback' => 'whitexmas_sanitize_checkbox',
		)
	);
	$wp_customize->add_control('whitexmas_hide_deer',		array(
		'type' => 'checkbox',
		'label' => __( 'No Christmas feeling? Check this box to hide the reindeer and snowflake.', 'white-xmas' ),
		'section' => 'header_image',
		)
	);
}
add_action( 'customize_register', 'whitexmas_customizer' );

/**
 * Checkbox sanitization callback, from https://github.com/WPTRT/code-examples/blob/master/customizer/sanitization-callbacks.php
 *
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function whitexmas_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}
